/*!
 *****************************************************************************
 * @file:   ADuCM410_Setup.c
 * @brief:  setup for ADuCM410
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2013-2018 Analog Devices, Inc. All Rights Reserved.

This software is proprietary to Analog Devices, Inc. and its licensors.
By using this software you agree to the terms of the associated
Analog Devices Software License Agreement.
 ******************************************************************************/

#include "GptLib.h"
#include "ClkLib.h"
#include "DacLib.h"
#include "DmaLib.h"
#include "AdcLib.h"
#include "SpiLib.h"
#include "SPI_port.h"

/*
   User can change following cofiguraion according to application
*/
CLK_SETUP_t gClkSetup = 
{
   //--------- configuration ---------
   .pllEn = 1,
   .rootClkMux = ENUM_CLOCK_CLKCON0_CLKMUX_SPLL,
   .analogClkMux = ENUM_CLOCK_CLKCON0_ANACLKMUX_HFOSC,
    

//-----------------Clock Divider -------------   
   .hclkDiv = ENUM_CLOCK_CLKCON1_CDHCLK_DIV2,
   .pclk0Div = ENUM_CLOCK_CLKCON1_CDPCLK0_DIV8,
   .pclk1Div = ENUM_CLOCK_CLKCON1_CDPCLK1_DIV8,
    
   .clockOff = 0x00000000,  //all clock on

   //---------Interrupt------------
   .pllIntEn = 0,    //0 - disalbe interrrupt related to PLL

   //-------TEST CLOCK -------
   .clkOutput = ENUM_CLOCK_CLKCON0_CLKOUT_B1_PCLK,
};

DMA_SETUP_t gDmaSetup =
{             
   .chanEn = DMA_SPI_TX_CHANNEL_BIT,   //enable SPI tx DMA channel
   .chanMask = 0, //no mask
   .useAlt = 0,   //use primary structure
   .priority = 0, //use defualt priority based on channel number
   .byteSwap = 0, //no byte swap
   .srcAddrDec = 0,  //no decreament
   .dstAddrDec = 0,  //no decreament
                //pointer to DMA channel description
   .pDmaChxDesc = NULL, //if NULL, it will be initialized in setup function
};


SPI_SETUP_t gSpi0Setup = 
{
   .spiEn = 1,
   .masterEn = 1,
   .cpha = 1,   //clock pahse
   .cpol = 1,      //clock polarity 
   .wireOrEn = 0,   //1 - SPI wire or mode 
   .lsbFirst = 0,   //0 - MSB transfered first
   .txTrigTransfer = 1, //0 - initiate transfer when read Rx reigster.
   .rxOverwrite = 1,//1 - Rx resigter is overwriten by new serial byte received
   .fifoEmtpyTx = FIFOEMPTY_TX_0,   //1 - send '0' when no valid data in Tx FIFO
   .misoEn = 1,  //1 - enable miso drive in slave mode
   .continousTx = 1,   //1 - transfer continous until no valid data in Tx register.
   .loopback = 0,   //1 - enable loopback
   .threePinMode = 0,  

   //----------- Interrupt -------------
   .txrxIrqByte = 0,//Interrupt Occurs After 4 Byte is Transfered or Received
   .csIntEn = 1,
   .txUnderflowIntEn = 0,
   .rxOverflowIntEn = 0,
   .readyIntEn = 0,
   .txDoneIntEn = 0,
   .frameEndIntEn = 0,
   .txFifoEmptyIntEn = 0,

   //------------- Dma -----------------
   .txDmaEn = 0,  //enable Dma 
   .rxDmaEn = 0,

   //-------------- Read command mode -----------
   .readCmdEn = 0, //0 - disable read command mode
   .txByte = 0,    //number of bytes to be transmitted before reading data
   .txRxOverlap = 0,
};
