/*!
 *****************************************************************************
 * @file:
 * @brief:
 *-----------------------------------------------------------------------------
 *
Copyright (c) 2013-2018 Analog Devices, Inc. All Rights Reserved.

This software is proprietary to Analog Devices, Inc. and its licensors.
By using this software you agree to the terms of the associated
Analog Devices Software License Agreement.
 ******************************************************************************/

#include "ADuCM410.h"
#include "WdtLib.h"
#include "common.h"
#include "DioLib.h"
#include "ClkLib.h"
#include "GptLib.h"
#include "DacLib.h"
#include "DmaLib.h"
#include "SpiLib.h"
#include "SPI_port.h"

#define SPI_MASTER_MODE 0

extern volatile uint32_t DmaDone;
#define SPI_TX_BUFFER_LEN 1000
extern uint16_t SpiTxBuf[SPI_TX_BUFFER_LEN];

extern void SpiInit(void);
extern void delay(uint32_t t);
extern void DmaInit(void);

#define SPI_DMA_TX_GO(pSPI) pSPI->DMA |= BITM_SPI_DMA_TXEN
#define SPI_DMA_TX_STOP(pSPI) pSPI->DMA &= ~BITM_SPI_DMA_TXEN

volatile uint32_t DmaDone = 0;
uint16_t SpiTxBuf[SPI_TX_BUFFER_LEN];

int main (void)
{
   DmaDone = 0;
   WdtGo(false);
   
   ClkSetup(&gClkSetup);
   
   
    SystemInit();
   INIT();
   SafetyWait();
   
   
   //init buffer
   for(uint32_t i=0;i<SPI_TX_BUFFER_LEN;i++)
   {
      SpiTxBuf[i] = (uint16_t)i;
   }
   
   DmaInit();
   SpiInit();
//   pSPI_INST->TX=0x11;
//   pSPI_INST->TX=0x22;
//   pSPI_INST->TX=0x33;
//   pSPI_INST->TX=0x44;
//   pSPI_INST->TX=0x55;
//   pSPI_INST->TX=0x66;
//   pSPI_INST->TX=0x77;
//   pSPI_INST->TX=0x88;
   pSPI_INST->DMA =1;
 
   SPI_DMA_TX_GO(pSPI_INST);
   
   while(DmaDone==0);
   DmaDone = 0; 
   
   while(1)
   {
      delay(10000);
      //WdtRefresh();
   }

}

void SpiInit()
{
   DioCfgPin(SPI_PORT,SPI_PIN_SCLK,SPI_PIN_SCLK_PINFUNC);
   DioCfgPin(SPI_PORT,SPI_PIN_MISO,SPI_PIN_MISO_PINFUNC);
   DioCfgPin(SPI_PORT,SPI_PIN_MOSI,SPI_PIN_MOSI_PINFUNC);
   DioCfgPin(SPI_PORT,SPI_PIN_CS,SPI_PIN_CS_PINFUNC);
   DioDsPin(SPI_PORT,SPI_PIN_SCLK,3);
   DioDsPin(SPI_PORT,SPI_PIN_MISO,3);
   DioDsPin(SPI_PORT,SPI_PIN_MOSI,3);
   DioDsPin(SPI_PORT,SPI_PIN_CS,3);
   
   SpiSetup(pSPI_INST,&gSpi0Setup);
   
#if SPI_MASTER_MODE
   //8MHz/(2*(1+div))
   SpiBaud(pSPI_INST,0);   //80/2=40MHz
 
   pSPI_INST->CNT = SPI_TX_BUFFER_LEN*2;        //ONLY required in master mode
   //pSPI_INST->TX=0xFF;  //write one byte to trigger transfer
#endif
}

void delay(uint32_t t)
{
   uint32_t i;
   for(i=0;i<t;i++);
}

void DmaInit()
{
   //DMA setup for SPI 
   DmaSetup(&gDmaSetup);
   //SPI DMA only support 16bit per transfer
   gDmaSetup.pDmaChxDesc[DMA_SPI_TX_CHANNEL].ctrlCfg.Bits.dst_inc = ENUM_DMA_INC_NO;   //no increment
   gDmaSetup.pDmaChxDesc[DMA_SPI_TX_CHANNEL].ctrlCfg.Bits.src_inc = ENUM_DMA_INC_HWORD;   //half word
   gDmaSetup.pDmaChxDesc[DMA_SPI_TX_CHANNEL].ctrlCfg.Bits.src_size = SIZE_HWORD;  //half word
   gDmaSetup.pDmaChxDesc[DMA_SPI_TX_CHANNEL].srcEndPtr = (uint32_t)(SpiTxBuf + SPI_TX_BUFFER_LEN - 1);
   gDmaSetup.pDmaChxDesc[DMA_SPI_TX_CHANNEL].destEndPtr = (uint32_t)(&pSPI_INST->TX);
   gDmaSetup.pDmaChxDesc[DMA_SPI_TX_CHANNEL].ctrlCfg.Bits.r_power = 0;  //2^0, 1 transaction each request
   gDmaSetup.pDmaChxDesc[DMA_SPI_TX_CHANNEL].ctrlCfg.Bits.n_minus_1 = SPI_TX_BUFFER_LEN-1; //8 bytes in total
   gDmaSetup.pDmaChxDesc[DMA_SPI_TX_CHANNEL].ctrlCfg.Bits.cycle_ctrl = 1;
   
   NVIC_EnableIRQ(DMA_SPI_TX_IRQn);
}

void DMA_SPI_TX_INT_HANDLER()
{
   DmaDone = 1;
   SPI_DMA_TX_STOP(pSPI_INST);
}

void SPI0_Int_Handler()
{
   DEBUG_PIN1_TOGGLE();
}  








